==> koffice2_1.9.95.orig.tar.gz: koffice-1.9.95/libs/main/KoDocumentInfoPropsPage.h <==
/* This file is part of the KDE project
   Copyright (c) 2000 Simon Hausmann <hausmann@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _koDocumentPropsPage_h_
#define _koDocumentPropsPage_h_

#include <kpropertiesdialog.h>
#include <komain_export.h>

#include <QString>

class KArchiveEntry;
class KOMAIN_EXPORT KoDocumentInfoPropsPage : public KPropertiesDialogPlugin
{
  Q_OBJECT

public:
    explicit KoDocumentInfoPropsPage( KPropertiesDialog *props,
                              const QStringList & = QStringList() );
    virtual ~KoDocumentInfoPropsPage();

    virtual void applyChanges();

private:
    void copy( const QString &path, const KArchiveEntry *entry );
    class KoDocumentInfoPropsPagePrivate;
    KoDocumentInfoPropsPagePrivate * const d;
};

#endif

==> koffice_2.2.0-7.tar.gz: koffice-2.2.0/libs/main/KoDocumentInfoPropsPage.h <==
/* This file is part of the KDE project
   Copyright (c) 2000 Simon Hausmann <hausmann@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _koDocumentPropsPage_h_
#define _koDocumentPropsPage_h_

#include <kpropertiesdialog.h>
#include "komain_export.h"

#include <QString>

class KArchiveEntry;
class KOMAIN_TEST_EXPORT KoDocumentInfoPropsPage : public KPropertiesDialogPlugin
{
    Q_OBJECT

public:
    explicit KoDocumentInfoPropsPage(KPropertiesDialog *props,
                                     const QStringList & = QStringList());
    virtual ~KoDocumentInfoPropsPage();

    virtual void applyChanges();

private:
    void copy(const QString &path, const KArchiveEntry *entry);
    class KoDocumentInfoPropsPagePrivate;
    KoDocumentInfoPropsPagePrivate * const d;
};

#endif
